#! /usr/bin/env python
# -*- coding: utf-8 -*-
# vim:fenc=utf-8

"""
Subpackage for SQLConnector subclass
"""

from meerschaum.connectors.sql._SQLConnector import SQLConnector

__all__ = ('SQLConnector',)
